This is the mail archive of the gcc-patches@gcc.gnu.org mailing list for the GCC project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

[patch] gcc: Follow spelling conventions.


Hi,

Attached is a patch to follow spelling conventions.  Committed as
obvious.

Kazu Hirata

2002-09-27  Kazu Hirata  <kazu@cs.umass.edu>

	* LANGUAGES: Follow spelling conventions.
	* rtl.def: Likewise.
	* sbitmap.c: Likewise.
	* sched-int.h: Likewise.
	* sched-rgn.c: Likewise.
	* sibcall.c: Likewise.
	* simplify-rtx.c: Likewise.
	* ssa.c: Likewise.
	* stab.def: Likewise.
	* stmt.c: Likewise.
	* stor-layout.c: Likewise.
	* target.h: Likewise.
	* timevar.c: Likewise.
	* toplev.c: Likewise.
	* tree-dump.c: Likewise.
	* tree-inline.c: Likewise.
	* tree.c: Likewise.
	* tree.def: Likewise.
	* tree.h: Likewise.
	* unroll.c: Likewise.
	* varasm.c: Likewise.
	* vmsdbgout.c: Likewise.
	* treelang/treelang.texi: Likewise.
	* treelang/treetree.c: Likewise.

Index: LANGUAGES
===================================================================
RCS file: /cvs/gcc/gcc/gcc/LANGUAGES,v
retrieving revision 1.11
diff -u -r1.11 LANGUAGES
--- LANGUAGES	26 Feb 2001 17:17:47 -0000	1.11
+++ LANGUAGES	27 Sep 2002 12:42:32 -0000
@@ -18,7 +18,7 @@
   from the input stream, and to push them back into the input stream respectively.
   The third argument is a pointer to a null terminate string which is the first
   word after #pragma.  The expression supplied by HANDLE_PRAGMA should return
-  non-zero if it parsed and implemented the pragma.  Otherwise it should return
+  nonzero if it parsed and implemented the pragma.  Otherwise it should return
   zero, and leave the input stream as it was before the expression was evaluated.
 
   A new back-end definable macro has been added: INSERT_ATTRIBUTES.  This macro
Index: rtl.def
===================================================================
RCS file: /cvs/gcc/gcc/gcc/rtl.def,v
retrieving revision 1.59
diff -u -r1.59 rtl.def
--- rtl.def	15 Aug 2002 01:03:43 -0000	1.59
+++ rtl.def	27 Sep 2002 12:42:34 -0000
@@ -864,7 +864,7 @@
 /* General conditional. The first operand is a vector composed of pairs of
    expressions.  The first element of each pair is evaluated, in turn.
    The value of the conditional is the second expression of the first pair
-   whose first expression evaluates non-zero.  If none of the expressions is
+   whose first expression evaluates nonzero.  If none of the expressions is
    true, the second operand will be used as the value of the conditional.
 
    This should be replaced with use of IF_THEN_ELSE.  */
Index: sbitmap.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/sbitmap.c,v
retrieving revision 1.22
diff -u -r1.22 sbitmap.c
--- sbitmap.c	15 Jul 2002 14:07:05 -0000	1.22
+++ sbitmap.c	27 Sep 2002 12:42:34 -0000
@@ -241,7 +241,7 @@
 }
 
 /* Set DST to be (A and B).
-   Return non-zero if any change is made.  */
+   Return nonzero if any change is made.  */
 
 bool
 sbitmap_a_and_b_cg (dst, a, b)
@@ -277,7 +277,7 @@
 }
 
 /* Set DST to be (A xor B)).
-   Return non-zero if any change is made.  */
+   Return nonzero if any change is made.  */
 
 bool
 sbitmap_a_xor_b_cg (dst, a, b)
@@ -313,7 +313,7 @@
 }
 
 /* Set DST to be (A or B)).
-   Return non-zero if any change is made.  */
+   Return nonzero if any change is made.  */
 
 bool
 sbitmap_a_or_b_cg (dst, a, b)
@@ -348,7 +348,7 @@
     *dstp++ = *ap++ | *bp++;
 }
 
-/* Return non-zero if A is a subset of B.  */
+/* Return nonzero if A is a subset of B.  */
 
 bool
 sbitmap_a_subset_b_p (a, b)
@@ -365,7 +365,7 @@
 }
 
 /* Set DST to be (A or (B and C)).
-   Return non-zero if any change is made.  */
+   Return nonzero if any change is made.  */
 
 bool
 sbitmap_a_or_b_and_c_cg (dst, a, b, c)
@@ -403,7 +403,7 @@
 }
 
 /* Set DST to be (A and (B or C)).
-   Return non-zero if any change is made.  */
+   Return nonzero if any change is made.  */
 
 bool
 sbitmap_a_and_b_or_c_cg (dst, a, b, c)
Index: sched-int.h
===================================================================
RCS file: /cvs/gcc/gcc/gcc/sched-int.h,v
retrieving revision 1.22
diff -u -r1.22 sched-int.h
--- sched-int.h	4 Jun 2002 17:46:13 -0000	1.22
+++ sched-int.h	27 Sep 2002 12:42:35 -0000
@@ -109,7 +109,7 @@
       int clobbers_length;
     } *reg_last;
 
-  /* Element N is set for each register that has any non-zero element
+  /* Element N is set for each register that has any nonzero element
      in reg_last[N].{uses,sets,clobbers}.  */
   regset_head reg_last_in_use;
 };
Index: sched-rgn.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/sched-rgn.c,v
retrieving revision 1.48
diff -u -r1.48 sched-rgn.c
--- sched-rgn.c	21 Jul 2002 22:01:58 -0000	1.48
+++ sched-rgn.c	27 Sep 2002 12:42:37 -0000
@@ -3001,7 +3001,7 @@
      first so that we can verify that live_at_start didn't change.  Then
      do all other blocks.  */
   /* ??? There is an outside possibility that update_life_info, or more
-     to the point propagate_block, could get called with non-zero flags
+     to the point propagate_block, could get called with nonzero flags
      more than once for one basic block.  This would be kinda bad if it
      were to happen, since REG_INFO would be accumulated twice for the
      block, and we'd have twice the REG_DEAD notes.
Index: sibcall.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/sibcall.c,v
retrieving revision 1.40
diff -u -r1.40 sibcall.c
--- sibcall.c	19 Sep 2002 00:10:10 -0000	1.40
+++ sibcall.c	27 Sep 2002 12:42:38 -0000
@@ -54,7 +54,7 @@
 /* Examine a CALL_PLACEHOLDER pattern and determine where the call's
    return value is located.  P_HARD_RETURN receives the hard register
    that the function used; P_SOFT_RETURN receives the pseudo register
-   that the sequence used.  Return non-zero if the values were located.  */
+   that the sequence used.  Return nonzero if the values were located.  */
 
 static int
 identify_call_return_value (cp, p_hard_return, p_soft_return)
Index: simplify-rtx.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/simplify-rtx.c,v
retrieving revision 1.121
diff -u -r1.121 simplify-rtx.c
--- simplify-rtx.c	17 Sep 2002 02:02:08 -0000	1.121
+++ simplify-rtx.c	27 Sep 2002 12:42:40 -0000
@@ -903,7 +903,7 @@
 	{
 	case PLUS:
 	  /* Maybe simplify x + 0 to x.  The two expressions are equivalent
-	     when x is NaN, infinite, or finite and non-zero.  They aren't
+	     when x is NaN, infinite, or finite and nonzero.  They aren't
 	     when x is -0 and the rounding mode is not towards -infinity,
 	     since (-0) + 0 is then 0.  */
 	  if (!HONOR_SIGNED_ZEROS (mode) && trueop1 == CONST0_RTX (mode))
@@ -1051,7 +1051,7 @@
 	    return CONST0_RTX (mode);
 
 	  /* Change subtraction from zero into negation.  (0 - x) is the
-	     same as -x when x is NaN, infinite, or finite and non-zero.
+	     same as -x when x is NaN, infinite, or finite and nonzero.
 	     But if the mode has signed zeros, and does not round towards
 	     -infinity, then 0 - 0 is 0, not -0.  */
 	  if (!HONOR_SIGNED_ZEROS (mode) && trueop0 == CONST0_RTX (mode))
Index: stab.def
===================================================================
RCS file: /cvs/gcc/gcc/gcc/stab.def,v
retrieving revision 1.5
diff -u -r1.5 stab.def
--- stab.def	6 Jan 1999 20:51:15 -0000	1.5
+++ stab.def	27 Sep 2002 12:42:42 -0000
@@ -84,7 +84,7 @@
 __define_stab (N_BROWS, 0x48, "BROWS")
 
 /* GNU Modula-2 definition module dependency.  Value is the modification time
-   of the definition file.  Other is non-zero if it is imported with the
+   of the definition file.  Other is nonzero if it is imported with the
    GNU M2 keyword %INITIALIZE.  Perhaps N_M2C can be used if there
    are enough empty fields? */
 __define_stab(N_DEFD, 0x4a, "DEFD")
Index: target.h
===================================================================
RCS file: /cvs/gcc/gcc/gcc/target.h,v
retrieving revision 1.36
diff -u -r1.36 target.h
--- target.h	13 Sep 2002 03:44:53 -0000	1.36
+++ target.h	27 Sep 2002 12:42:50 -0000
@@ -99,7 +99,7 @@
     void (* eh_frame_section) PARAMS ((void));
 
     /* Select and switch to a section for EXP.  It may be a DECL or a
-       constant for which TREE_CST_RTL is valid.  RELOC is non-zero if
+       constant for which TREE_CST_RTL is valid.  RELOC is nonzero if
        runtime relocations must be applied; bit 1 will be set if the
        runtime relocations require non-local name resolution.  ALIGN is
        the required alignment of the data.  */
Index: timevar.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/timevar.c,v
retrieving revision 1.20
diff -u -r1.20 timevar.c
--- timevar.c	18 May 2002 15:16:23 -0000	1.20
+++ timevar.c	27 Sep 2002 12:42:50 -0000
@@ -114,7 +114,7 @@
 
 /* See timevar.h for an explanation of timing variables.  */
 
-/* This macro evaluates to non-zero if timing variables are enabled.  */
+/* This macro evaluates to nonzero if timing variables are enabled.  */
 #define TIMEVAR_ENABLE (time_report)
 
 /* A timing variable.  */
Index: tree-dump.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/tree-dump.c,v
retrieving revision 1.7
diff -u -r1.7 tree-dump.c
--- tree-dump.c	26 Jul 2002 13:45:34 -0000	1.7
+++ tree-dump.c	27 Sep 2002 12:42:55 -0000
@@ -592,7 +592,7 @@
   fprintf (di->stream, "\n");
 }
 
-/* Return non-zero if FLAG has been specified for the dump, and NODE
+/* Return nonzero if FLAG has been specified for the dump, and NODE
    is not the root node of the dump.  */
 
 int dump_flag (di, flag, node)
@@ -709,7 +709,7 @@
   return stream;
 }
 
-/* Returns non-zero if tree dump PHASE is enabled.  */
+/* Returns nonzero if tree dump PHASE is enabled.  */
 
 int
 dump_enabled_p (phase)
@@ -738,7 +738,7 @@
   fclose (stream);
 }
 
-/* Parse ARG as a dump switch. Return non-zero if it is, and store the
+/* Parse ARG as a dump switch. Return nonzero if it is, and store the
    relevant details in the dump_files array.  */
 
 int
Index: tree-inline.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/tree-inline.c,v
retrieving revision 1.30
diff -u -r1.30 tree-inline.c
--- tree-inline.c	8 Sep 2002 12:47:27 -0000	1.30
+++ tree-inline.c	27 Sep 2002 12:42:57 -0000
@@ -831,7 +831,7 @@
     return NULL_TREE;
 }
 
-/* Returns non-zero if a function can be inlined as a tree.  */
+/* Returns nonzero if a function can be inlined as a tree.  */
 
 int
 tree_inlinable_function_p (fn)
@@ -840,7 +840,7 @@
   return inlinable_function_p (fn, NULL);
 }
 
-/* Returns non-zero if FN is a function that can be inlined into the
+/* Returns nonzero if FN is a function that can be inlined into the
    inlining context ID_.  If ID_ is NULL, check whether the function
    can be inlined at all.  */
 
Index: tree.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/tree.c,v
retrieving revision 1.273
diff -u -r1.273 tree.c
--- tree.c	17 Sep 2002 13:03:40 -0000	1.273
+++ tree.c	27 Sep 2002 12:43:01 -0000
@@ -2599,7 +2599,7 @@
   return false;
 }
 
-/* Return non-zero if IDENT is a valid name for attribute ATTR,
+/* Return nonzero if IDENT is a valid name for attribute ATTR,
    or zero if not.
 
    We try both `text' and `__text__', ATTR may be either one.  */
Index: tree.def
===================================================================
RCS file: /cvs/gcc/gcc/gcc/tree.def,v
retrieving revision 1.52
diff -u -r1.52 tree.def
--- tree.def	25 May 2002 20:18:41 -0000	1.52
+++ tree.def	27 Sep 2002 12:43:02 -0000
@@ -76,10 +76,10 @@
    could either point to another BLOCK node or it could point to a
    FUNCTION_DECL node (e.g. in the case of a block representing the
    outermost scope of a particular inlining of a function).
-   BLOCK_ABSTRACT is non-zero if the block represents an abstract
+   BLOCK_ABSTRACT is nonzero if the block represents an abstract
    instance of a block (i.e. one which is nested within an abstract
    instance of an inline function). 
-   TREE_ASM_WRITTEN is non-zero if the block was actually referenced
+   TREE_ASM_WRITTEN is nonzero if the block was actually referenced
    in the generated assembly.  */
 DEFTREECODE (BLOCK, "block", 'b', 0)
 
@@ -329,7 +329,7 @@
    holds a line number.  In some cases these can be the location of
    a reference, if no definition has been seen.
 
-   DECL_ABSTRACT is non-zero if the decl represents an abstract instance
+   DECL_ABSTRACT is nonzero if the decl represents an abstract instance
    of a decl (i.e. one which is nested within an abstract instance of a
    inline function.  */
 
Index: tree.h
===================================================================
RCS file: /cvs/gcc/gcc/gcc/tree.h,v
retrieving revision 1.353
diff -u -r1.353 tree.h
--- tree.h	20 Sep 2002 07:33:25 -0000	1.353
+++ tree.h	27 Sep 2002 12:43:05 -0000
@@ -53,7 +53,7 @@
 extern const char tree_code_type[];
 #define TREE_CODE_CLASS(CODE)	tree_code_type[(int) (CODE)]
 
-/* Returns non-zero iff CLASS is the tree-code class of an
+/* Returns nonzero iff CLASS is the tree-code class of an
    expression.  */
 
 #define IS_EXPR_CODE_CLASS(CLASS) \
@@ -1375,7 +1375,7 @@
    as DECL_NAME.  It is an IDENTIFIER_NODE.  */
 #define DECL_ASSEMBLER_NAME(NODE) decl_assembler_name (NODE)
 
-/* Returns non-zero if the DECL_ASSEMBLER_NAME for NODE has been set.  If zero,
+/* Returns nonzero if the DECL_ASSEMBLER_NAME for NODE has been set.  If zero,
    the NODE might still have a DECL_ASSEMBLER_NAME -- it just hasn't been set
    yet.  */
 #define DECL_ASSEMBLER_NAME_SET_P(NODE) \
@@ -1495,7 +1495,7 @@
    : (make_decl_rtl (NODE, NULL), (NODE)->decl.rtl))
 /* Set the DECL_RTL for NODE to RTL.  */
 #define SET_DECL_RTL(NODE, RTL) (DECL_CHECK (NODE)->decl.rtl = (RTL))
-/* Returns non-zero if the DECL_RTL for NODE has already been set.  */
+/* Returns nonzero if the DECL_RTL for NODE has already been set.  */
 #define DECL_RTL_SET_P(NODE)  (DECL_CHECK (NODE)->decl.rtl != NULL)
 /* Copy the RTL from NODE1 to NODE2.  If the RTL was not set for
    NODE1, it will not be set for NODE2; this is a lazy copy.  */
@@ -1608,7 +1608,7 @@
 /* In a FIELD_DECL, indicates this field should be bit-packed.  */
 #define DECL_PACKED(NODE) (FIELD_DECL_CHECK (NODE)->decl.regdecl_flag)
 
-/* In a FUNCTION_DECL with a non-zero DECL_CONTEXT, indicates that a
+/* In a FUNCTION_DECL with a nonzero DECL_CONTEXT, indicates that a
    static chain is not needed.  */
 #define DECL_NO_STATIC_CHAIN(NODE) \
   (FUNCTION_DECL_CHECK (NODE)->decl.regdecl_flag)
@@ -2317,7 +2317,7 @@
 
 extern int valid_machine_attribute	PARAMS ((tree, tree, tree, tree));
 
-/* Given a tree node and a string, return non-zero if the tree node is
+/* Given a tree node and a string, return nonzero if the tree node is
    a valid attribute name for the string.  */
 
 extern int is_attribute_p		PARAMS ((const char *, tree));
@@ -2516,7 +2516,7 @@
 /* If nonzero, an upper limit on alignment of structure fields, in bits.  */
 extern unsigned int maximum_field_alignment;
 
-/* If non-zero, the alignment of a bitstring or (power-)set value, in bits.  */
+/* If nonzero, the alignment of a bitstring or (power-)set value, in bits.  */
 extern unsigned int set_alignment;
 
 /* Concatenate two lists (chains of TREE_LIST nodes) X and Y
Index: unroll.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/unroll.c,v
retrieving revision 1.176
diff -u -r1.176 unroll.c
--- unroll.c	8 Sep 2002 18:32:31 -0000	1.176
+++ unroll.c	27 Sep 2002 12:43:09 -0000
@@ -170,7 +170,7 @@
   UNROLL_NAIVE
 };
 
-/* Indexed by register number, if non-zero, then it contains a pointer
+/* Indexed by register number, if nonzero, then it contains a pointer
    to a struct induction for a DEST_REG giv which has been combined with
    one of more address givs.  This is needed because whenever such a DEST_REG
    giv is modified, we must modify the value of all split address givs
@@ -2482,7 +2482,7 @@
 	 it is unsafe to split the biv since it may not have the proper
 	 value on loop exit.  */
 
-      /* loop_number_exit_count is non-zero if the loop has an exit other than
+      /* loop_number_exit_count is nonzero if the loop has an exit other than
 	 a fall through at the end.  */
 
       biv_splittable = 1;
@@ -2507,7 +2507,7 @@
 	    || GET_CODE (SET_SRC (tem)) != PLUS)
 	  biv_splittable = 0;
 
-      /* If final value is non-zero, then must emit an instruction which sets
+      /* If final value is nonzero, then must emit an instruction which sets
 	 the value of the biv to the proper value.  This is done after
 	 handling all of the givs, since some of them may need to use the
 	 biv's value in their initialization code.  */
@@ -2567,7 +2567,7 @@
       result += find_splittable_givs (loop, bl, unroll_type, increment,
 				      unroll_number);
 
-      /* If final value is non-zero, then must emit an instruction which sets
+      /* If final value is nonzero, then must emit an instruction which sets
 	 the value of the biv to the proper value.  This is done after
 	 handling all of the givs, since some of them may need to use the
 	 biv's value in their initialization code.  */
@@ -2696,7 +2696,7 @@
       /* Should emit insns after the loop if possible, as the biv final value
 	 code below does.  */
 
-      /* If the final value is non-zero, and the giv has not been reduced,
+      /* If the final value is nonzero, and the giv has not been reduced,
 	 then must emit an instruction to set the final value.  */
       if (final_value && !v->new_reg)
 	{
Index: vmsdbgout.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/vmsdbgout.c,v
retrieving revision 1.19
diff -u -r1.19 vmsdbgout.c
--- vmsdbgout.c	15 Aug 2002 19:59:29 -0000	1.19
+++ vmsdbgout.c	27 Sep 2002 12:43:15 -0000
@@ -526,7 +526,7 @@
 
 /* Output the debug header HEADER.  Also output COMMENT if flag_verbose_asm is
    set.  Return the header size.  Just return the size if DOSIZEONLY is
-   non-zero.  */
+   nonzero.  */
 
 static int
 write_debug_header (header, comment, dosizeonly)
@@ -558,7 +558,7 @@
 
 /* Output the address of SYMBOL.  Also output COMMENT if flag_verbose_asm is
    set.  Return the address size.  Just return the size if DOSIZEONLY is
-   non-zero.  */
+   nonzero.  */
 
 static int
 write_debug_addr (symbol, comment, dosizeonly)
@@ -579,7 +579,7 @@
 
 /* Output the single byte DATA1.  Also output COMMENT if flag_verbose_asm is
    set.  Return the data size.  Just return the size if DOSIZEONLY is
-   non-zero.  */
+   nonzero.  */
 
 static int
 write_debug_data1 (data1, comment, dosizeonly)
@@ -600,7 +600,7 @@
 
 /* Output the single word DATA2.  Also output COMMENT if flag_verbose_asm is
    set.  Return the data size.  Just return the size if DOSIZEONLY is
-   non-zero.  */
+   nonzero.  */
 
 static int
 write_debug_data2 (data2, comment, dosizeonly)
@@ -620,7 +620,7 @@
 }
 
 /* Output double word DATA4.  Also output COMMENT if flag_verbose_asm is set.
-   Return the data size.  Just return the size if DOSIZEONLY is non-zero.  */
+   Return the data size.  Just return the size if DOSIZEONLY is nonzero.  */
 
 static int
 write_debug_data4 (data4, comment, dosizeonly)
@@ -640,7 +640,7 @@
 }
 
 /* Output quad word DATA8.  Also output COMMENT if flag_verbose_asm is set.
-   Return the data size.  Just return the size if DOSIZEONLY is non-zero.  */
+   Return the data size.  Just return the size if DOSIZEONLY is nonzero.  */
 
 static int
 write_debug_data8 (data8, comment, dosizeonly)
@@ -661,7 +661,7 @@
 
 /* Output the difference between LABEL1 and LABEL2.  Also output COMMENT if
    flag_verbose_asm is set.  Return the data size.  Just return the size if
-   DOSIZEONLY is non-zero.  */
+   DOSIZEONLY is nonzero.  */
 
 static int
 write_debug_delta4 (label1, label2, comment, dosizeonly)
@@ -683,7 +683,7 @@
 
 /* Output a character string STRING.  Also write COMMENT if flag_verbose_asm is
    set.  Return the string length.  Just return the length if DOSIZEONLY is
-   non-zero.  */
+   nonzero.  */
 
 static int
 write_debug_string (string, comment, dosizeonly)
@@ -703,7 +703,7 @@
 }
 
 /* Output a module begin header and return the header size.  Just return the
-   size if DOSIZEONLY is non-zero.  */
+   size if DOSIZEONLY is nonzero.  */
 
 static int
 write_modbeg (dosizeonly)
@@ -767,7 +767,7 @@
 }
 
 /* Output a module end trailer and return the trailer size.   Just return
-   the size if DOSIZEONLY is non-zero.  */
+   the size if DOSIZEONLY is nonzero.  */
 
 static int
 write_modend (dosizeonly)
@@ -787,7 +787,7 @@
 }
 
 /* Output a routine begin header routine RTNNUM and return the header size.
-   Just return the size if DOSIZEONLY is non-zero.  */
+   Just return the size if DOSIZEONLY is nonzero.  */
 
 static int
 write_rtnbeg (rtnnum, dosizeonly)
@@ -882,7 +882,7 @@
 }
 
 /* Output a routine end trailer for routine RTNNUM and return the header size.
-   Just return the size if DOSIZEONLY is non-zero.  */
+   Just return the size if DOSIZEONLY is nonzero.  */
 
 static int
 write_rtnend (rtnnum, dosizeonly)
@@ -926,7 +926,7 @@
   : (I) < 65536 ? DST_K_INCR_LINUM_W : DST_K_INCR_LINUM_L)
 
 /* Output the PC to line number correlations and return the size.  Just return
-   the size if DOSIZEONLY is non-zero */
+   the size if DOSIZEONLY is nonzero */
 
 static int
 write_pclines (dosizeonly)
@@ -1057,7 +1057,7 @@
 
 /* Output a source correlation for file FILEID using information saved in
    FILE_INFO_ENTRY and return the size.  Just return the size if DOSIZEONLY is
-   non-zero.  */
+   nonzero.  */
 
 static int
 write_srccorr (fileid, file_info_entry, dosizeonly)
@@ -1252,7 +1252,7 @@
 }
 
 /* Output all the source correlation entries and return the size.  Just return
-   the size if DOSIZEONLY is non-zero.  */
+   the size if DOSIZEONLY is nonzero.  */
 
 static int
 write_srccorrs (dosizeonly)
Index: treelang/treelang.texi
===================================================================
RCS file: /cvs/gcc/gcc/gcc/treelang/treelang.texi,v
retrieving revision 1.3
diff -u -r1.3 treelang.texi
--- treelang/treelang.texi	15 Sep 2002 22:48:06 -0000	1.3
+++ treelang/treelang.texi	27 Sep 2002 12:43:31 -0000
@@ -601,7 +601,7 @@
 if_statement: if (expression) @{ statements @} else @{ statements @}
 
 The first lot of statements is executed if the expression is
-non-zero. Otherwise the second lot of statements is executed. Either
+nonzero. Otherwise the second lot of statements is executed. Either
 list of statements may be empty, but both sets of braces and the else must be present. 
 
 @smallexample
Index: treelang/treetree.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/treelang/treetree.c,v
retrieving revision 1.11
diff -u -r1.11 treetree.c
--- treelang/treetree.c	9 Sep 2002 20:52:30 -0000	1.11
+++ treelang/treetree.c	27 Sep 2002 12:43:32 -0000
@@ -199,7 +199,7 @@
                  exp, 
                  build1 (CONVERT_EXPR, TREE_TYPE (exp), integer_zero_node));
   emit_line_note ((const char *)filename, lineno); /* Output the line number information.  */
-  expand_start_cond (cond_exp, /* Exit-able if non zero.  */ 0);
+  expand_start_cond (cond_exp, /* Exit-able if nonzero.  */ 0);
 }
 
 /* Output the code for the else of an if statement.  The else occurred


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Index: ssa.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/ssa.c,v
retrieving revision 1.55
diff -u -r1.55 ssa.c
--- ssa.c	27 Sep 2002 00:50:50 -0000	1.55
+++ ssa.c	27 Sep 2002 12:42:42 -0000
@@ -78,7 +78,7 @@
    the same hard register in the same machine mode are in the same
    class.  */
 
 /* If conservative_reg_partition is non-zero, use a conservative
    register partitioning algorithm (which leaves more regs after
    emerging from SSA) instead of the coalescing one.  This is being
    left in for a limited time only, as a debugging tool until the
@@ -420,7 +420,7 @@
 }
 
 /* Given the SET of a phi node, remove the alternative for predecessor
-   block C.  Return non-zero on success, or zero if no alternative is
+   block C.  Return nonzero on success, or zero if no alternative is
    found for C.  */
 
 int
@@ -1496,7 +1496,7 @@
      and C is the ith predecessor of B,
      then T0 and Ti must be equivalent.
 
-   Return non-zero iff any such cases were found for which the two
+   Return nonzero iff any such cases were found for which the two
    regs were not already in the same class.  */
 
 static int
@@ -2252,7 +2252,7 @@
    destination, the regno of the phi argument corresponding to BB,
    and DATA.
 
-   If FN ever returns non-zero, stops immediately and returns this
+   If FN ever returns nonzero, stops immediately and returns this
    value.  Otherwise, returns zero.  */
 
 int
@@ -78,7 +78,7 @@
    class.  */
 
-/* If conservative_reg_partition is non-zero, use a conservative
+/* If conservative_reg_partition is nonzero, use a conservative
    register partitioning algorithm (which leaves more regs after
    emerging from SSA) instead of the coalescing one.  This is being
Index: stmt.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/stmt.c,v
retrieving revision 1.270
diff -u -r1.270 stmt.c
--- stmt.c	23 Sep 2002 12:17:51 -0000	1.270
+++ stmt.c	27 Sep 2002 12:42:48 -0000
@@ -2821,7 +2821,7 @@
   return (cfun->stmt == NULL || loop_stack == NULL);
 }
 
 /* Return non-zero if we should preserve sub-expressions as separate
    pseudos.  We never do so if we aren't optimizing.  We always do so
    if -fexpensive-optimizations.
 
@@ -3434,7 +3434,7 @@
   pop_temp_slots ();
 }
 
 /* Given a pointer to a BLOCK node return non-zero if (and only if) the node
    in question represents the outermost pair of curly braces (i.e. the "body
    block") of a function or method.
 
@@ -4234,7 +4234,7 @@
    This is sometimes used to avoid a cleanup associated with
    a value that is being returned out of the scope.
 
-   If IN_FIXUP is non-zero, we are generating this cleanup for a fixup
+   If IN_FIXUP is nonzero, we are generating this cleanup for a fixup
    goto and handle protection regions specially in that case.
 
    If REACHABLE, we emit code, otherwise just inform the exception handling
@@ -2821,7 +2821,7 @@
 }
 
-/* Return non-zero if we should preserve sub-expressions as separate
+/* Return nonzero if we should preserve sub-expressions as separate
    pseudos.  We never do so if we aren't optimizing.  We always do so
    if -fexpensive-optimizations.
@@ -3434,7 +3434,7 @@
 }
 
-/* Given a pointer to a BLOCK node return non-zero if (and only if) the node
+/* Given a pointer to a BLOCK node return nonzero if (and only if) the node
    in question represents the outermost pair of curly braces (i.e. the "body
    block") of a function or method.
Index: stor-layout.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/stor-layout.c,v
retrieving revision 1.129
diff -u -r1.129 stor-layout.c
--- stor-layout.c	18 Sep 2002 18:51:13 -0000	1.129
+++ stor-layout.c	27 Sep 2002 12:42:50 -0000
@@ -48,7 +48,7 @@
    The value is measured in bits.  */
 unsigned int maximum_field_alignment;
 
 /* If non-zero, the alignment of a bitstring or (power-)set value, in bits.
    May be overridden by front-ends.  */
 unsigned int set_alignment = 0;
 
@@ -96,7 +96,7 @@
   return chain;
 }
 
 /* Return non-zero if EXPR is present on the pending sizes list.  */
 
 int
 is_pending_size (expr)
@@ -807,7 +807,7 @@
 	 affect the alignment of a record; even a zero-sized field
 	 can do this.  The alignment should be to the alignment of
 	 the type, except that for zero-size bitfields this only
-	 applies if there was an immediately prior, non-zero-size
+	 applies if there was an immediately prior, nonzero-size
 	 bitfield.  (That's the way it is, experimentally.) */
       if (! integer_zerop (DECL_SIZE (field))
  	  ? ! DECL_PACKED (field)
@@ -48,7 +48,7 @@
 unsigned int maximum_field_alignment;
 
-/* If non-zero, the alignment of a bitstring or (power-)set value, in bits.
+/* If nonzero, the alignment of a bitstring or (power-)set value, in bits.
    May be overridden by front-ends.  */
 unsigned int set_alignment = 0;
@@ -96,7 +96,7 @@
 }
 
-/* Return non-zero if EXPR is present on the pending sizes list.  */
+/* Return nonzero if EXPR is present on the pending sizes list.  */
 
 int
Index: toplev.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/toplev.c,v
retrieving revision 1.676
diff -u -r1.676 toplev.c
--- toplev.c	21 Sep 2002 16:10:29 -0000	1.676
+++ toplev.c	27 Sep 2002 12:42:55 -0000
@@ -346,8 +346,8 @@
 int optimize = 0;
 
 /* Nonzero means optimize for size.  -Os.
-   The only valid values are zero and non-zero. When optimize_size is
-   non-zero, optimize defaults to 2, but certain individual code
+   The only valid values are zero and nonzero. When optimize_size is
+   nonzero, optimize defaults to 2, but certain individual code
    bloating optimizations are disabled.  */
 
 int optimize_size = 0;
@@ -1893,7 +1893,7 @@
 /* Do any final processing required for the declarations in VEC, of
    which there are LEN.  We write out inline functions and variables
    that have been deferred until this point, but which are required.
-   Returns non-zero if anything was put out.  */
+   Returns nonzero if anything was put out.  */
 
 int
 wrapup_global_declarations (vec, len)
@@ -4732,7 +4732,7 @@
    minimal options processing.  Outputting diagnostics is OK, but GC
    and identifier hashtables etc. are not initialized yet.
 
-   Return non-zero to suppress compiler back end initialization.  */
+   Return nonzero to suppress compiler back end initialization.  */
 static void
 parse_options_and_default_flags (argc, argv)
      int argc;
@@ -5180,7 +5180,7 @@
   expand_dummy_function_end ();
 }
 
 /* Language-dependent initialization.  Returns non-zero on success.  */
 static int
 lang_dependent_init (name)
      const char *name;
@@ -5180,7 +5180,7 @@
 }
 
-/* Language-dependent initialization.  Returns non-zero on success.  */
+/* Language-dependent initialization.  Returns nonzero on success.  */
 static int
 lang_dependent_init (name)
Index: varasm.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/varasm.c,v
retrieving revision 1.311
diff -u -r1.311 varasm.c
--- varasm.c	20 Sep 2002 17:50:47 -0000	1.311
+++ varasm.c	27 Sep 2002 12:43:14 -0000
@@ -195,7 +195,7 @@
 #endif
 } in_section = no_section;
 
 /* Return a non-zero value if DECL has a section attribute.  */
 #ifndef IN_NAMED_SECTION
 #define IN_NAMED_SECTION(DECL) \
   ((TREE_CODE (DECL) == FUNCTION_DECL || TREE_CODE (DECL) == VAR_DECL) \
@@ -1138,7 +1138,7 @@
 #endif
 
 /* CONSTANT_POOL_BEFORE_FUNCTION may be defined as an expression with
-   a non-zero value if the constant pool should be output before the
+   a nonzero value if the constant pool should be output before the
    start of the function, or a zero value if the pool should output
    after the end of the function.  The default is to put it before the
    start.  */
@@ -1945,7 +1945,7 @@
 
 /* Assemble the integer constant X into an object of SIZE bytes.  ALIGN is
    the alignment of the integer in bits.  Return 1 if we were able to output
-   the constant, otherwise 0.  If FORCE is non-zero, abort if we can't output
+   the constant, otherwise 0.  If FORCE is nonzero, abort if we can't output
    the constant.  */
 
 bool
@@ -2228,7 +2228,7 @@
   return STRHASH (((const struct deferred_string *) x)->label);
 }
 
 /* Returns non-zero if the value represented by X (which is really a
    struct deferred_string *) is the same as that given by Y
    (which is really a char *).  */
 
@@ -2648,7 +2648,7 @@
    Otherwise, output such a constant in memory (or defer it for later)
    and generate an rtx for it.
 
-   If DEFER is non-zero, the output of string constants can be deferred
+   If DEFER is nonzero, the output of string constants can be deferred
    and output only if referenced in the function after all optimizations.
 
    The TREE_CST_RTL of EXP is set up to point to that rtx.
@@ -195,7 +195,7 @@
 } in_section = no_section;
 
-/* Return a non-zero value if DECL has a section attribute.  */
+/* Return a nonzero value if DECL has a section attribute.  */
 #ifndef IN_NAMED_SECTION
 #define IN_NAMED_SECTION(DECL) \
@@ -2228,7 +2228,7 @@
 }
 
-/* Returns non-zero if the value represented by X (which is really a
+/* Returns nonzero if the value represented by X (which is really a
    struct deferred_string *) is the same as that given by Y
    (which is really a char *).  */